@@ -1,5 +1,4 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
- *
+/*
  * Copyright (C) 2008-2013 Red Hat, Inc.
  *
  * Licensed under GPL version 2 or later.
@@ -39,6 +38,7 @@ typedef struct
   GtkWidget *symbolic_icon_entry;
 
   GVariant *orig_fstab_entry;
+  gboolean is_swap;
 } FstabDialogData;
 
 static void
@@ -189,21 +189,25 @@ fstab_on_device_combobox_changed (GtkComboBox *combobox,
                                   gpointer     user_data)
 {
   FstabDialogData *data = user_data;
-  gchar *fsname;
-  gchar *proposed_mount_point;
-  const gchar *s;
 
-  fsname = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (data->device_combobox));
-  s = strrchr (fsname, '/');
-  if (s == NULL)
-    s = strrchr (fsname, '=');
-  if (s == NULL)
-    s = "/disk";
-  proposed_mount_point = g_strdup_printf ("/mnt/%s", s + 1);
+  if (!data->is_swap)
+    {
+      gchar *fsname;
+      gchar *proposed_mount_point;
+      const gchar *s;
 
-  gtk_entry_set_text (GTK_ENTRY (data->directory_entry), proposed_mount_point);
-  g_free (proposed_mount_point);
-  g_free (fsname);
+      fsname = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (data->device_combobox));
+      s = strrchr (fsname, '/');
+      if (s == NULL)
+        s = strrchr (fsname, '=');
+      if (s == NULL)
+        s = "/disk";
+      proposed_mount_point = g_strdup_printf ("/mnt/%s", s + 1);
+
+      gtk_entry_set_text (GTK_ENTRY (data->directory_entry), proposed_mount_point);
+      g_free (proposed_mount_point);
+      g_free (fsname);
+  }
 
   update_device_explanation (data);
 }
@@ -405,6 +409,8 @@ gdu_fstab_dialog_show (GduWindow    *window,
   data.icon_entry = GTK_WIDGET (gtk_builder_get_object (builder, "fstab-icon-entry"));
   data.symbolic_icon_entry = GTK_WIDGET (gtk_builder_get_object (builder, "fstab-symbolic-icon-entry"));
 
+  data.is_swap = (udisks_object_peek_swapspace (object) != NULL);
+
   /* there could be multiple fstab entries - we only consider the first one */
   g_variant_iter_init (&iter, udisks_block_get_configuration (block));
   while (g_variant_iter_next (&iter, "(&s@a{sv})", &configuration_type, &configuration_dict))
@@ -448,6 +454,18 @@ gdu_fstab_dialog_show (GduWindow    *window,
                                    drive,
                                    block,
                                    fsname);
+  if (data.is_swap)
+    {
+      dir = "none";
+      type = "swap";
+      opts = "sw";
+      gtk_widget_set_sensitive (data.directory_entry, FALSE);
+      gtk_widget_set_sensitive (data.show_checkbutton, FALSE);
+      gtk_widget_set_sensitive (data.name_entry, FALSE);
+      gtk_widget_set_sensitive (data.icon_entry, FALSE);
+      gtk_widget_set_sensitive (data.symbolic_icon_entry, FALSE);
+    }
+
   gtk_entry_set_text (GTK_ENTRY (data.directory_entry), dir);
   gtk_entry_set_text (GTK_ENTRY (data.type_entry), type);
   gtk_entry_set_text (GTK_ENTRY (data.options_entry), opts);
